@@ -1,6 +1,13 @@
-/* demo/rakuraku/miss/miss1.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -23,7 +30,7 @@ static logical c_true = TRUE_;
 static real c_b36 = .3f;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -72,7 +79,7 @@ static real c_b36 = .3f;
     e_rsle();
     gropn_(&iws);
     grfrm_();
-/* -- »ͽʤ ---- */
+/* -- 欠損値処理なし ---- */
     grswnd_(&c_b7, &c_b8, &c_b9, &c_b10);
     grsvpt_(&c_b11, &c_b12, &c_b13, &c_b12);
     grstrn_(&c__1);
@@ -84,7 +91,7 @@ static real c_b36 = .3f;
     grstrf_();
     sgspmt_(&c__3);
     sgpmu_(&c__41, x, y);
-/* -- »ͽ ---- */
+/* -- 欠損値処理 ---- */
     gllset_("LMISS", &c_true, (ftnlen)5);
     grswnd_(&c_b7, &c_b8, &c_b9, &c_b10);
     grsvpt_(&c_b11, &c_b12, &c_b36, &c_b23);
