@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -14,32 +14,34 @@
 
 /* Table of constant values */
 
-static integer c__23 = 23;
+static integer c__29 = 29;
 static integer c__1 = 1;
 static integer c__3 = 3;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int sgtrqf_0_(int n__, integer *ntx, logical *ltr, char *cts,
 	 char *ctl, ftnlen cts_len, ftnlen ctl_len)
 {
     /* Initialized data */
 
-    static char ctr1[3*23] = "U-U" "U-L" "L-U" "L-L" "POL" "BPL" "ELP" "CYL" 
+    static char ctr1[3*29] = "U-U" "U-L" "L-U" "L-L" "POL" "BPL" "ELP" "CYL" 
 	    "MER" "MWD" "HMR" "EK6" "KTD" "CON" "COA" "COC" "BON" "OTG" "PST" 
-	    "AZM" "AZA" "GTR" "USR";
-    static char ctr2[20*23] = "UNI-UNI             " "UNI-LOG             " 
+	    "AZM" "AZA" "GTR" "USR" "MIL" "RBS" "SIN" "VDG" "PLC" "GNO";
+    static char ctr2[20*29] = "UNI-UNI             " "UNI-LOG             " 
 	    "LOG-UNI             " "LOG-LOG             " "POLAR            "
-	    "   " "BIPOLAR             " "ELLIPTIC            " "CYLINDRICAL "
-	    "        " "MERCATOR            " "MOLLWEIDE           " "HAMMER "
+	    "   " "BIPOLAR             " "ELLIPTIC            " "EQDST. CYLIN"
+	    "DRICAL  " "MERCATOR            " "MOLLWEIDE           " "HAMMER "
 	    "             " "ECKERT 6            " "KITADA              " 
-	    "CONICAL             " "CONICAL EQ. AREA    " "CONICAL CONFORMAL"
-	    "   " "BONNE               " "ORTHOGRAPHIC        " "POLAR STEREO"
-	    "        " "AZIMUTHAL           " "AZIMUTHAL EQ. AREA  " "GRIDBAS"
-	    "E TRANSFORM  " "USER                ";
-    static integer ntr[23] = { 1,2,3,4,5,6,7,10,11,12,13,14,15,20,21,22,23,30,
-	    31,32,33,51,99 };
+	    "PTOLEMAIC CONICAL   " "EQ.-AREA CONICAL    " "CONFORMAL CONICAL"
+	    "   " "BONNE               " "ORTHOGRAPHIC        " "STEREOGRAPHI"
+	    "C       " "EQUIDST. AZIMUTHAL  " "AZIMUTHAL EQ. AREA  " "GRIDBAS"
+	    "E TRANSFORM  " "USER                " "MILLER              " 
+	    "ROBINSON            " "SANSON/SINUSOIDAL   " "VAN DER GRINTEN  "
+	    "   " "POLYCONIC           " "GNOMONIC            ";
+    static integer ntr[29] = { 1,2,3,4,5,6,7,10,11,12,13,14,15,20,21,22,23,30,
+	    31,32,33,51,99,16,17,18,19,24,34 };
 
     /* System generated locals */
     address a__1[3];
@@ -69,12 +71,12 @@ static integer c__3 = 3;
 	case 6: goto L_sgtrnl;
 	}
 
-    *ltr = indxif_(ntr, &c__23, &c__1, ntx) != 0;
+    *ltr = indxif_(ntr, &c__29, &c__1, ntx) != 0;
     return 0;
 /* ----------------------------------------------------------------------- */
 
 L_sgtrsl:
-    for (n = 1; n <= 23; ++n) {
+    for (n = 1; n <= 29; ++n) {
 	if (lchreq_(cts, ctr1 + (n - 1) * 3, cts_len, (ftnlen)3)) {
 	    s_copy(ctl, ctr2 + (n - 1) * 20, ctl_len, (ftnlen)20);
 	    return 0;
@@ -92,7 +94,7 @@ L_sgtrsl:
 /* ----------------------------------------------------------------------- */
 
 L_sgtrsn:
-    for (n = 1; n <= 23; ++n) {
+    for (n = 1; n <= 29; ++n) {
 	if (lchreq_(cts, ctr1 + (n - 1) * 3, cts_len, (ftnlen)3)) {
 	    *ntx = ntr[n - 1];
 	    return 0;
@@ -110,7 +112,7 @@ L_sgtrsn:
 /* ----------------------------------------------------------------------- */
 
 L_sgtrls:
-    for (n = 1; n <= 23; ++n) {
+    for (n = 1; n <= 29; ++n) {
 	if (lchreq_(ctl, ctr2 + (n - 1) * 20, ctl_len, (ftnlen)20)) {
 	    s_copy(cts, ctr1 + (n - 1) * 3, cts_len, (ftnlen)3);
 	    return 0;
@@ -128,7 +130,7 @@ L_sgtrls:
 /* ----------------------------------------------------------------------- */
 
 L_sgtrln:
-    for (n = 1; n <= 23; ++n) {
+    for (n = 1; n <= 29; ++n) {
 	if (lchreq_(ctl, ctr2 + (n - 1) * 20, ctl_len, (ftnlen)20)) {
 	    *ntx = ntr[n - 1];
 	    return 0;
@@ -146,7 +148,7 @@ L_sgtrln:
 /* ----------------------------------------------------------------------- */
 
 L_sgtrns:
-    for (n = 1; n <= 23; ++n) {
+    for (n = 1; n <= 29; ++n) {
 	if (*ntx == ntr[n - 1]) {
 	    s_copy(cts, ctr1 + (n - 1) * 3, cts_len, (ftnlen)3);
 	    return 0;
@@ -161,7 +163,7 @@ L_sgtrns:
 /* ----------------------------------------------------------------------- */
 
 L_sgtrnl:
-    for (n = 1; n <= 23; ++n) {
+    for (n = 1; n <= 29; ++n) {
 	if (*ntx == ntr[n - 1]) {
 	    s_copy(ctl, ctr2 + (n - 1) * 20, ctl_len, (ftnlen)20);
 	    return 0;
