@@ -149,6 +149,12 @@ static void zgcatl(void);
 
 static char fontlist[255] = { 41, 42, 43, 44, 55, 66, 77, 85, 95 };
 
+//  Full Color index */
+static double rt2,gt2,bt2,rl2,gl2,bl2;
+static int ifcidx=998;
+//Background color index
+static int ibgcli=999;
+
 
 /* For using system font. some internal variables of SGPACK*/
 static int sg_lfprop, sg_lcntl, sg_isup, sg_isub, sg_irst;
@@ -619,16 +625,28 @@ void ZGDOPN(DCL_INT *dev_type,
 
   if ((idev_type == IWS_FILE) && ( ifl == IFL_EPS || ifl == IFL_PDF)){
     if (((PS_PAGE_HEIGHT - ipsy *2) / iwidth) > ((PS_PAGE_WIDTH - ipsx *2 )/ iheight)){
+      if((PS_PAGE_HEIGHT < iwidth + ipsx * 2) || (PS_PAGE_WIDTH < iheight + ipsy * 2)){
+        PS_PAGE_WIDTH=iheight + ipsy * 2;
+        PS_PAGE_HEIGHT=iwidth + ipsx * 2;
+      }
       iPS_PAGE_WIDTH   = PS_PAGE_WIDTH - ipsx * 2;
       iPS_PAGE_HEIGHT  = (PS_PAGE_WIDTH - ipsx * 2) * iwidth / iheight;
+      PS_PAGE_WIDTH=iPS_PAGE_WIDTH + ipsx *2;
+      PS_PAGE_HEIGHT=PS_PAGE_WIDTH * 842 / 595;
       offx = ipsx;
       offy = ipsy + (PS_PAGE_HEIGHT - ipsy *2 - iPS_PAGE_HEIGHT )/2;
       if(dlnscale==999.){
         dlnscale = (DCL_REAL)iPS_PAGE_WIDTH / iwidth ;
       }
     }else{
+      if((PS_PAGE_HEIGHT < iwidth + ipsx * 2) || (PS_PAGE_WIDTH < iheight + ipsy * 2)){
+        PS_PAGE_WIDTH=iheight + ipsy * 2;
+        PS_PAGE_HEIGHT=iwidth + ipsx * 2;
+      }
       iPS_PAGE_WIDTH   = (PS_PAGE_HEIGHT -ipsy*2) * iheight / iwidth;
       iPS_PAGE_HEIGHT  = PS_PAGE_HEIGHT - ipsy*2;
+      PS_PAGE_HEIGHT=iPS_PAGE_HEIGHT + ipsy *2;
+      PS_PAGE_WIDTH=PS_PAGE_HEIGHT * 595 / 842;
       offx = ipsx + (PS_PAGE_WIDTH  - ipsx *2 - iPS_PAGE_WIDTH)/2;
       offy = ipsy;
       if(dlnscale==999.){
@@ -794,6 +812,10 @@ void ZGDCLS(void)
     if (!wait_np && wait_cl) {
       next = FALSE;
       ifunc = DCLS;
+      while (1) {
+        gtk_main_iteration();
+        if (next) break;
+      }
     }
   }
   if (idev_type == IWS_FILE){
@@ -1029,12 +1051,21 @@ void ZGSCLI(DCL_INT *iclidx)
 
   if (!lfcmod){
 
-  iclidz = *iclidx % MAXCLI;
-
-  rt1 = (double) cx[iclidz].red   / 65535;
-  gt1 = (double) cx[iclidz].green / 65535;
-  bt1 = (double) cx[iclidz].blue  / 65535;
+  if (*iclidx == ibgcli) {
+    iclidz=0;
+  }else{
+    iclidz = *iclidx % MAXCLI;
+  }
 
+  if(*iclidx==ifcidx){
+    rt1=rl2;
+    gt1=gl2;
+    bt1=bl2;
+  }else{
+    rt1 = (double) cx[iclidz].red   / 65535;
+    gt1 = (double) cx[iclidz].green / 65535;
+    bt1 = (double) cx[iclidz].blue  / 65535;
+  }
   cairo_set_source_rgb(cr,rt1,gt1,bt1);
   }
 /*if (iclidz == 0)
@@ -2104,11 +2135,20 @@ void ZGGTON(DCL_INT *np, DCL_REAL wpx[], DCL_REAL wpy[], DCL_INT *itpat)
   }
 
   //  ibit = *itpat % 1000;
-  iclr = (*itpat / 1000) % MAXCLI;
-  if ((*itpat / 1000) == 999){ iclr=0;}
-  rt1 = (double) cx[iclr].red   / 65535;
-  gt1 = (double) cx[iclr].green / 65535;
-  bt1 = (double) cx[iclr].blue  / 65535;
+  if (*itpat/1000 == ibgcli) {
+    iclr=0;
+  }else{
+    iclr = (*itpat / 1000) % MAXCLI;
+  }
+  if ((*itpat / 1000) == ifcidx){
+    rt1=rt2;
+    gt1=gt2;
+    bt1=bt2;
+  }else{
+    rt1 = (double) cx[iclr].red   / 65535;
+    gt1 = (double) cx[iclr].green / 65535;
+    bt1 = (double) cx[iclr].blue  / 65535;
+  }
 
   cairo_set_source_rgb(crb,rt1,gt1,bt1);
   cairo_rectangle(crb,0.0,0.0,16.0,16.0);
@@ -2368,17 +2408,17 @@ void ZGSLCL(DCL_INT *icolor)
 {
   GdkColor loccx;
 
-  double rt1,gt1,bt1;
+//  double rt1,gt1,bt1;
 
   loccx.red   = ((*icolor >> 16) & 255) * 256;
   loccx.green = ((*icolor >> 8)  & 255) * 256;
   loccx.blue  = ((*icolor >> 0)  & 255) * 256;
 
-  rt1 = (double) loccx.red   / 65535;
-  gt1 = (double) loccx.green / 65535;
-  bt1 = (double) loccx.blue  / 65535;
+  rl2 = (double) loccx.red   / 65535;
+  gl2 = (double) loccx.green / 65535;
+  bl2 = (double) loccx.blue  / 65535;
 
-  cairo_set_source_rgb(cr,rt1,gt1,bt1);
+  cairo_set_source_rgb(cr,rl2,gl2,bl2);
 }
 
 #ifndef WINDOWS
@@ -2403,9 +2443,9 @@ void ZGSTCL(DCL_INT *icolor)
   loccx.green = ((*icolor >> 8)  & 255) * 256;
   loccx.blue  = ((*icolor >> 0)  & 255) * 256;
 
-  rt1 = (double) loccx.red   / 65535;
-  gt1 = (double) loccx.green / 65535;
-  bt1 = (double) loccx.blue  / 65535;
+  rt2 = (double) loccx.red   / 65535;
+  gt2 = (double) loccx.green / 65535;
+  bt2 = (double) loccx.blue  / 65535;
 
   cairo_set_source_rgb(cr,rt1,gt1,bt1);
 }
