@@ -33,6 +33,9 @@ struct {
 
 static logical c_true = TRUE_;
 static integer c__92 = 92;
+static integer c__32 = 32;
+static integer c__180 = 180;
+static integer c__182 = 182;
 
 /* ----------------------------------------------------------------------- */
 /*     BASIC TEXT PRIMITIVE ON VC */
@@ -57,7 +60,6 @@ static integer c__92 = 92;
 
     /* Local variables */
     static char fontname[70];
-    static logical markfont;
     static integer i__, j, k, n, nc, ip;
     static real xc, yc;
     static integer nx, ny;
@@ -86,30 +88,48 @@ static integer c__92 = 92;
     static real factz, irota;
     static integer ifont;
     static real xrate, yrate;
-    static integer nskip;
-    static real rxmin, rymin, rxmax, rymax;
-    static integer iwtrf, iposx[2048];
+    static integer nskip, isubz;
+    static real rxmin, rxmax, rymin, rymax;
+    static integer iposx[2048];
     static real wxmin, wxmax, wymin, wymax;
+    static integer iwtrf, isupz, irstz;
     extern /* Subroutine */ int swsfw_(integer *), swtxt_(real *, real *, 
-	    real *, char *, integer *, real *, integer *, ftnlen), sgiget_(
-	    char *, integer *, ftnlen), sglget_(char *, logical *, ftnlen), 
-	    msgdmp_(char *, char *, char *, ftnlen, ftnlen, ftnlen), swcget_(
-	    char *, char *, ftnlen, ftnlen), swftfc_(char *, ftnlen);
+	    real *, char *, integer *, real *, integer *, ftnlen);
+    static integer iocmde, iocmod;
+    extern /* Subroutine */ int sgiget_(char *, integer *, ftnlen), sglget_(
+	    char *, logical *, ftnlen), msgdmp_(char *, char *, char *, 
+	    ftnlen, ftnlen, ftnlen), swcget_(char *, char *, ftnlen, ftnlen), 
+	    swftfc_(char *, ftnlen);
     static logical lfprop;
     extern /* Subroutine */ int swscli_(integer *, logical *), swlget_(char *,
-	     logical *, ftnlen), swocls_(char *, ftnlen), szfint_(integer *), 
+	     logical *, ftnlen);
+    static logical lcntlz;
+    extern /* Subroutine */ int swocls_(char *, ftnlen), szfint_(integer *), 
 	    szqidx_(integer *), szclsv_(void), szqfnt_(integer *, char *, 
 	    char *, ftnlen, ftnlen), szqfnw_(real *, real *), stfwtr_(real *, 
 	    real *, real *, real *), szplsv_(real *, real *), stqwtr_(real *, 
 	    real *, real *, real *, real *, real *, real *, real *, integer *)
 	    , szopsv_(void), szmvsv_(real *, real *), szqtxw_(char *, integer 
 	    *, real *, real *, ftnlen);
-    static logical sysfont;
+    static logical lmrkfnt, lsysfnt;
 
+    lcntlz = szbtx2_1.lcntl;
+    sgiget_("ISUP", &isup, (ftnlen)4);
+    sgiget_("ISUB", &isub, (ftnlen)4);
+    sgiget_("IRST", &irst, (ftnlen)4);
+    isupz = 29;
+    isubz = 30;
+    irstz = 31;
+    csgi_(ch__1, (ftnlen)1, &isupz);
+    *(unsigned char *)csup = *(unsigned char *)&ch__1[0];
+    csgi_(ch__1, (ftnlen)1, &isubz);
+    *(unsigned char *)csub = *(unsigned char *)&ch__1[0];
+    csgi_(ch__1, (ftnlen)1, &irstz);
+    *(unsigned char *)crst = *(unsigned char *)&ch__1[0];
 /*      / START: CODE FOR USING SYSTEN FONTS / */
 /*      / PROCCESS IF NOT MARKER / */
-    swlget_("SYSFONT", &sysfont, (ftnlen)7);
-    if (sysfont) {
+    swlget_("LSYSFNT", &lsysfnt, (ftnlen)7);
+    if (lsysfnt) {
 	szqidx_(&index);
 	swcget_("FONTNAME", fontname, (ftnlen)8, (ftnlen)70);
 /*     / WHEN FONTNAME IS NOT GIVEN / */
@@ -134,8 +154,8 @@ static integer c__92 = 92;
 	    swftfc_(fontname, (ftnlen)70);
 	}
 	idx = isgc_(chars, (ftnlen)1);
-	sglget_("MARKFONT", &markfont, (ftnlen)8);
-	if (idx > 18 || markfont) {
+	sglget_("LMRKFNT", &lmrkfnt, (ftnlen)7);
+	if (idx > 18 || lmrkfnt) {
 	    ncz = lenc_(chars, chars_len);
 	    stfwtr_(vx, vy, &wx, &wy);
 	    stqwtr_(&rxmin, &rxmax, &rymin, &rymax, &wxmin, &wxmax, &wymin, &
@@ -210,37 +230,42 @@ static integer c__92 = 92;
 	s_copy(charz, " ", (ftnlen)2048, (ftnlen)1);
 /* L1: */
     }
-    sgiget_("ISUP", &isup, (ftnlen)4);
-    sgiget_("ISUB", &isub, (ftnlen)4);
-    sgiget_("IRST", &irst, (ftnlen)4);
-    csgi_(ch__1, (ftnlen)1, &isup);
-    *(unsigned char *)csup = *(unsigned char *)&ch__1[0];
-    csgi_(ch__1, (ftnlen)1, &isub);
-    *(unsigned char *)csub = *(unsigned char *)&ch__1[0];
-    csgi_(ch__1, (ftnlen)1, &irst);
-    *(unsigned char *)crst = *(unsigned char *)&ch__1[0];
     nskip = 0;
     idest = 1;
     imode = 0;
+    iocmde = 0;
     lmark = TRUE_;
     i__1 = ncz;
     for (n = 1; n <= i__1; ++n) {
 	idx0 = isgc_(charx + (n - 1), (ftnlen)1);
+	if (idx0 == isupz || idx0 == isubz || idx0 == irstz) {
+	    csgi_(ch__1, (ftnlen)1, &c__32);
+	    *(unsigned char *)&charx[n - 1] = *(unsigned char *)&ch__1[0];
+	    idx0 = isgc_(charx + (n - 1), (ftnlen)1);
+	}
 	if (imode == 1) {
 	    if (idx0 == 94) {
+		lcntlz = TRUE_;
 		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)csup;
 		++idest;
 	    } else if (idx0 == 95) {
+		lcntlz = TRUE_;
 		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)csub;
 		++idest;
 	    } else if (idx0 == 111) {
-		*(unsigned char *)&charz[idest - 1] = '~';
+/*           180: UP ARROW */
+		csgi_(ch__1, (ftnlen)1, &c__180);
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
+			ch__1[0];
 		++idest;
 		msgdmp_("W", "SZTXWV", "TOPBAR IS NOT SUPPORT IN STROKEFONT", 
 			(ftnlen)1, (ftnlen)6, (ftnlen)35);
 		lmark = FALSE_;
 	    } else if (idx0 == 117) {
-		*(unsigned char *)&charz[idest - 1] = '~';
+/*           182: DOWN ARROW */
+		csgi_(ch__1, (ftnlen)1, &c__182);
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
+			ch__1[0];
 		++idest;
 		msgdmp_("W", "SZTXWV", "UNDERBAR IS NOT SUPPORT IN STROKEFONT"
 			, (ftnlen)1, (ftnlen)6, (ftnlen)37);
@@ -281,9 +306,39 @@ static integer c__92 = 92;
 			charx[n - 1];
 		++idest;
 	    }
-/*       92:\ 94:^ 95:_ 111:o 117:u 120:u 123:{ 125:} */
+/*       92:\ 94:^ 95:_ 111:o 117:u 123:{ 125:} */
 	} else if (idx0 == 92) {
 	    imode = 1;
+/* OLD TYPE CONTROL */
+	} else if (idx0 == isup && szbtx2_1.lcntl) {
+	    csgi_(ch__1, (ftnlen)1, &isup);
+	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&ch__1[0];
+	    iocmde = idest;
+	    ++idest;
+	} else if (idx0 == isub && szbtx2_1.lcntl) {
+	    csgi_(ch__1, (ftnlen)1, &isub);
+	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&ch__1[0];
+	    iocmde = -idest;
+	    ++idest;
+	} else if (idx0 == irst && szbtx2_1.lcntl) {
+	    if (iocmde > 0) {
+		*(unsigned char *)&charz[iocmde - 1] = *(unsigned char *)csup;
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)crst;
+		++idest;
+		iocmod = 0;
+	    } else if (iocmde < 0) {
+		i__2 = -iocmde - 1;
+		s_copy(charz + i__2, csub, -iocmde - i__2, (ftnlen)1);
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)crst;
+		++idest;
+		iocmod = 0;
+	    } else {
+		csgi_(ch__1, (ftnlen)1, &irst);
+		*(unsigned char *)&charz[idest - 1] = *(unsigned char *)&
+			ch__1[0];
+		iocmde = 0;
+		++idest;
+	    }
 	} else {
 	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)&charx[n 
 		    - 1];
@@ -291,18 +346,11 @@ static integer c__92 = 92;
 	}
 /* L3: */
     }
-    if (imode != 0) {
-	if (idest <= ncz) {
-	    *(unsigned char *)&charz[idest - 1] = *(unsigned char *)crst;
-	    ++idest;
-	}
-	msgdmp_("W", "SZTXWV", "MARKUP IS NOT IN GOOD AGREEMENT.", (ftnlen)1, 
-		(ftnlen)6, (ftnlen)32);
-    }
     if (idest <= ncz) {
 	ncz = idest - 1;
     }
 /*  / END CONVERT MARKUPS / */
+    lcntlz = TRUE_;
     szqtxw_(charz, &nc, &wxch, &wych, (ftnlen)2048);
 /*     / CALCULATE OFFSET VALUES / */
     offx = wxch * -.5f * 24.f * (szbtx1_1.icentz + 1);
@@ -319,17 +367,17 @@ static integer c__92 = 92;
     for (k = 1; k <= i__1; ++k) {
 /*       / CHARACTER CONVERSION / */
 	idx = isgc_(charz + (k - 1), (ftnlen)1) + 1;
-	ips = iposx[idx - 1] + 1;
 /*       / CHECK CONTROL CHARACTERS / */
-	if (szbtx2_1.lcntl && (idx == szbtx2_1.jsub || idx == szbtx2_1.jsup ||
-		 idx == szbtx2_1.jrst)) {
-	    if (idx == szbtx2_1.jsub) {
+	ips = iposx[idx - 1] + 1;
+	if (lcntlz && (idx == isubz + 1 || idx == isupz + 1 || idx == irstz + 
+		1)) {
+	    if (idx == isubz + 1) {
 		mode = -1;
 		factz = szbtx2_1.small;
-	    } else if (idx == szbtx2_1.jsup) {
+	    } else if (idx == isupz + 1) {
 		mode = 1;
 		factz = szbtx2_1.small;
-	    } else if (idx == szbtx2_1.jrst) {
+	    } else if (idx == irstz + 1) {
 		mode = 0;
 		factz = 1.f;
 	    }
