@@ -20,20 +20,28 @@ struct {
 
 #define szbtx3_1 szbtx3_
 
+/* Table of constant values */
+
+static logical c_false = FALSE_;
+
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int sztxzr_(real *rx, real *ry, char *chars, ftnlen 
 	chars_len)
 {
-    extern /* Subroutine */ int stepr2_(void), strpr2_(void);
+    extern /* Subroutine */ int stepr2_(void), strpr2_(void), sglget_(char *, 
+	    logical *, ftnlen);
     static logical lclipz;
-    extern /* Subroutine */ int sztxwv_(real *, real *, char *, ftnlen);
+    extern /* Subroutine */ int sglset_(char *, logical *, ftnlen), sztxwv_(
+	    real *, real *, char *, ftnlen);
 
-    lclipz = szbtx3_1.lclip;
+    sglget_("LCLIP", &lclipz, (ftnlen)5);
+    sglset_("LCLIP", &c_false, (ftnlen)5);
     szbtx3_1.lclip = FALSE_;
     stepr2_();
     sztxwv_(rx, ry, chars, chars_len);
+    sglset_("LCLIP", &lclipz, (ftnlen)5);
     szbtx3_1.lclip = lclipz;
     strpr2_();
     return 0;
