@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -12,19 +12,14 @@
 
 #include "libtinyf2c.h"
 
-/* Table of constant values */
-
-static logical c_true = TRUE_;
-
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int gropn_0_(int n__, integer *iws)
 {
     extern /* Subroutine */ int sgcls_(void), sgfrm_(void), grinit_(void), 
 	    sginit_(void), uminit_(void), usinit_(void), uuinit_(void), 
-	    sgistx_(char *, integer *, ftnlen), uzinit_(void), sglstx_(char *,
-	     logical *, ftnlen);
+	    uwinit_(void), sgistx_(char *, integer *, ftnlen), uzinit_(void);
 
 /*     / OPEN / */
     switch(n__) {
@@ -35,7 +30,6 @@ static logical c_true = TRUE_;
 
     sgistx_("IWS", iws, (ftnlen)3);
     sginit_();
-    sglstx_("LCNTL", &c_true, (ftnlen)5);
     return 0;
 /* ----------------------------------------------------------------------- */
 
@@ -47,6 +41,7 @@ L_grfrm:
     uzinit_();
     uminit_();
     uuinit_();
+    uwinit_();
     return 0;
 /* ----------------------------------------------------------------------- */
 
@@ -57,6 +52,7 @@ L_grfig:
     uzinit_();
     uminit_();
     uuinit_();
+    uwinit_();
     return 0;
 /* ----------------------------------------------------------------------- */
 
