@@ -140,7 +140,7 @@ static integer c__16 = 16;
     sgiget_("IRST", &irst, (ftnlen)4);
     gllget_("LEPSL", &lepsl, (ftnlen)5);
     sglget_("LCNTL", &lcntl, (ftnlen)5);
-    swlget_("SYSFONT", &lsfnt, (ftnlen)7);
+    swlget_("LSYSFNT", &lsfnt, (ftnlen)7);
     gllset_("LEPSL", &c_true, (ftnlen)5);
     gnsave_();
 /*     SMALL TICKS */
