@@ -1,6 +1,13 @@
-/* src/grph2/umpack/umpfit.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -13,7 +20,7 @@ static real c_b6 = 0.f;
 /* ----------------------------------------------------------------------- */
 /*     SET MAPPING PARAMETERS */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int umpfit_(void)
 {
@@ -83,7 +90,7 @@ static real c_b6 = 0.f;
 /* Computing MIN */
 	r__1 = (vxmaxz - vxminz) / (xmax - xmin), r__2 = (vymaxz - vyminz) / (
 		ymax - ymin);
-	radius = dmin(r__1,r__2);
+	radius = min(r__1,r__2);
     }
     if (vxoff == rundef) {
 	vxoff = (vxmaxz + vxminz - (xmax + xmin)) / 2.f * radius;
