@@ -74,7 +74,7 @@ static integer c__2 = 2;
 
 
     sglget_("LCNTL", &lcntl, (ftnlen)5);
-    swlget_("SYSFONT", &lsfnt, (ftnlen)7);
+    swlget_("LSYSFNT", &lsfnt, (ftnlen)7);
     glrget_("REPSL", &prec, (ftnlen)5);
     nprec = -r_lg10(&prec);
     if (nprec > 8) {
