@@ -1,6 +1,13 @@
-/* src/grph2/uspack/ususcu.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -16,7 +23,7 @@ static integer c__1 = 1;
 /* ----------------------------------------------------------------------- */
 /*     USPACK AUTO SCALING ROUTINE (UNIFORM)           DCL 5.0  95/09/04 */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int ususcu_(char *caxis, real *umin, real *umax, real *vmin, 
 	real *vmax, integer *mode, ftnlen caxis_len)
@@ -58,7 +65,7 @@ static integer c__1 = 1;
     static integer ntry;
     static real ufac0, uoff0;
     static char ccfmt[8];
-    extern doublereal rgnge_(real *);
+    extern real rgnge_(real *);
     static logical lepsl;
     extern /* Subroutine */ int gllget_(char *, logical *, ftnlen), gnsblk_(
 	    real *, integer *);
@@ -104,8 +111,8 @@ static integer c__1 = 1;
     s_cat(cdut, a__1, i__1, &c__3, (ftnlen)8);
     usrget_(cdut, &dut, (ftnlen)8);
     if (dut == rundef) {
-	rmin = dmin(*umin,*umax);
-	rmax = dmax(*umin,*umax);
+	rmin = min(*umin,*umax);
+	rmax = max(*umin,*umax);
 	usurdt_(&rmin, &rmax, vmin, vmax, &dut);
 	usrset_(cdut, &dut, (ftnlen)8);
     }
@@ -115,8 +122,8 @@ static integer c__1 = 1;
     gnsave_();
     gnsblk_(sc1, &c__4);
     gnle_(&dut, &bx, &iexp);
-    rmin = dmin(*umin,*umax);
-    rmax = dmax(*umin,*umax);
+    rmin = min(*umin,*umax);
+    rmax = max(*umin,*umax);
     u2v = (*vmax - *vmin) / (rmax - rmin);
 /* Writing concatenation */
     i__1[0] = 1, a__1[0] = "D";
@@ -163,7 +170,7 @@ static integer c__1 = 1;
 	    }
 	    ifac = (integer) (fac + .1f);
 	    dul = dut * ifac;
-	    dul = dmax(dul,dul0);
+	    dul = max(dul,dul0);
 	    if (ifac < 10) {
 		goto L200;
 	    }
