@@ -1,6 +1,13 @@
-/* src/grph2/uspack/uszdgt.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -13,7 +20,7 @@ static doublereal c_b18 = 10.;
 /* ----------------------------------------------------------------------- */
 /*      USPACK NUMBER OF DIGIT                        S. Sakai  89/03/23 */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int uszdgt_(real *umin, real *umax, real *dul, integer *
 	maxdgt, real *uoff, real *ufact, integer *ndgt, integer *ldgt)
@@ -78,12 +85,12 @@ static doublereal c_b18 = 10.;
 	umaxf = (nmax - iuoff) * *dul;
 	uminf = (nmin - iuoff) * *dul;
 	if (uminf != 0.f) {
-	    r__2 = dabs(uminf);
+	    r__2 = abs(uminf);
 	    r__1 = r_lg10(&r__2);
 	    nmn = irle_(&r__1);
 	}
 	if (umaxf != 0.f) {
-	    r__2 = dabs(umaxf);
+	    r__2 = abs(umaxf);
 	    r__1 = r_lg10(&r__2);
 	    nmx = irle_(&r__1);
 	}
