@@ -1,6 +1,13 @@
-/* src/math1/maplib/mpfmer.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -8,7 +15,7 @@
 /* ----------------------------------------------------------------------- */
 /*     MAP PROJECTION (MERCATOR)                        93/02/20 S.SAKAI */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int mpfmer_0_(int n__, real *xlon, real *ylat, real *x, real 
 	*y)
@@ -19,10 +26,10 @@
 
     /* Local variables */
     static real pi, rna;
-    extern doublereal rfpi_(void);
+    extern real rfpi_(void);
     static real theta;
     extern /* Subroutine */ int glrget_(char *, real *, ftnlen);
-    extern doublereal xmplon_(real *);
+    extern real xmplon_(real *);
 
     switch(n__) {
 	case 1: goto L_mpimer;
@@ -44,7 +51,7 @@
 L_mpimer:
     pi = rfpi_();
     *xlon = *x;
-    if (dabs(*xlon) <= pi) {
+    if (abs(*xlon) <= pi) {
 	*ylat = atan(exp(*y)) * 2 - pi / 2;
 	return 0;
     }
