@@ -1,6 +1,13 @@
-/* src/math2/fftlib/radf5.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -31,7 +38,7 @@
     ch -= ch_offset;
     cc_dim1 = *ido;
     cc_dim2 = *l1;
-    cc_offset = 1 + cc_dim1 * (1 + cc_dim2 * 1);
+    cc_offset = 1 + cc_dim1 * (1 + cc_dim2);
     cc -= cc_offset;
     --wa1;
     --wa2;
