@@ -1,7 +1,7 @@
 /*
  *	dclvnm
  *
- *    Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+ *    Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
  *
  */
 
@@ -9,12 +9,14 @@
 #include <string.h>
 
 #ifndef DCLVER
-#define DCLVER "dcl-ver.5"
+#define DCLVER "dcl-ver.7.1.1"
 #endif
 
-void dclvnm_(cvname, Lvname)
-    char *cvname;
-    int  Lvname;
+#ifndef WINDOWS
+void dclvnm_(char *cvname, int Lvname)
+#else
+void DCLVNM(char *cvname, int Lvname)
+#endif
 {
     int minlen, lbuf;
     char *dclver, *buf;
